==> huaweicloudsdkcss-3.1.133-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/update_instance_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateInstanceRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'instance_id': 'str'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'instance_id': 'instance_id'
    }

    def __init__(self, cluster_id=None, instance_id=None):
        """UpdateInstanceRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 指定替换集群ID。
        :type cluster_id: str
        :param instance_id: 指定替换节点ID。
        :type instance_id: str
        """
        
        

        self._cluster_id = None
        self._instance_id = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.instance_id = instance_id

    @property
    def cluster_id(self):
        """Gets the cluster_id of this UpdateInstanceRequest.

        指定替换集群ID。

        :return: The cluster_id of this UpdateInstanceRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this UpdateInstanceRequest.

        指定替换集群ID。

        :param cluster_id: The cluster_id of this UpdateInstanceRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def instance_id(self):
        """Gets the instance_id of this UpdateInstanceRequest.

        指定替换节点ID。

        :return: The instance_id of this UpdateInstanceRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this UpdateInstanceRequest.

        指定替换节点ID。

        :param instance_id: The instance_id of this UpdateInstanceRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateInstanceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcss-3.1.152-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/update_instance_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateInstanceRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'instance_id': 'str'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'instance_id': 'instance_id'
    }

    def __init__(self, cluster_id=None, instance_id=None):
        r"""UpdateInstanceRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 指定替换集群ID。
        :type cluster_id: str
        :param instance_id: 指定替换节点ID。
        :type instance_id: str
        """
        
        

        self._cluster_id = None
        self._instance_id = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.instance_id = instance_id

    @property
    def cluster_id(self):
        r"""Gets the cluster_id of this UpdateInstanceRequest.

        指定替换集群ID。

        :return: The cluster_id of this UpdateInstanceRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        r"""Sets the cluster_id of this UpdateInstanceRequest.

        指定替换集群ID。

        :param cluster_id: The cluster_id of this UpdateInstanceRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def instance_id(self):
        r"""Gets the instance_id of this UpdateInstanceRequest.

        指定替换节点ID。

        :return: The instance_id of this UpdateInstanceRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        r"""Sets the instance_id of this UpdateInstanceRequest.

        指定替换节点ID。

        :param instance_id: The instance_id of this UpdateInstanceRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateInstanceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
